@@ -6,7 +6,8 @@ int cmd_mouseup(context_t *context) {
   int button;
   char *cmd = *context->argv;
   char *window_arg = NULL;
-  xdo_active_mods_t *active_mods = NULL;
+  charcodemap_t *active_mods = NULL;
+  int active_mods_n;
   int clear_modifiers = 0;
 
   int c;
@@ -54,19 +55,19 @@ int cmd_mouseup(context_t *context) {
 
   window_each(context, window_arg, {
     if (clear_modifiers) {
-      active_mods = xdo_get_active_modifiers(context->xdo);
-      xdo_clear_active_modifiers(context->xdo, window, active_mods);
+      xdo_get_active_modifiers(context->xdo, &active_mods, &active_mods_n);
+      xdo_clear_active_modifiers(context->xdo, window, active_mods, active_mods_n);
     }
 
-    ret = xdo_mouseup(context->xdo, window, button);
+    ret = xdo_mouse_up(context->xdo, window, button);
 
     if (clear_modifiers) {
-      xdo_set_active_modifiers(context->xdo, window, active_mods);
-      xdo_free_active_modifiers(active_mods);
+      xdo_set_active_modifiers(context->xdo, window, active_mods, active_mods_n);
+      free(active_mods);
     }
 
     if (ret) {
-      fprintf(stderr, "xdo_mouseup reported an error on window %ld\n", window);
+      fprintf(stderr, "xdo_mouse_up reported an error on window %ld\n", window);
       return ret;
     }
   }); /* window_each(...) */
